@@ -1,7 +1,7 @@
-lm.beta <- 
-function (linmod, dummy.na = TRUE)
+lm.beta <-
+function (linmod, dummy.na = TRUE) # funktioniert!
 {
-  
+
   linmod_data <- linmod$model
   var_dep <- linmod_data[,1]
 
@@ -33,7 +33,7 @@ function (linmod, dummy.na = TRUE)
     coeff[i] <- linmod$coefficients[i+var_dep_col]
 
     if ((dummy.na == TRUE) && (all(linmod_data[,i+1] %in% c(1,0)))) { coeff_stand[i] <- NA }
-
+   
     else
     {
       sd_varind[i] <- sd(linmod_data[,i+1])
@@ -48,4 +48,4 @@ function (linmod, dummy.na = TRUE)
 
   return(coeff_stand_list)
 
-}
\ No newline at end of file
+}
